<?php
namespace Tygh\Shippings\Services;

use Tygh\Shippings\IService;
use Tygh\Registry;

class SmilepayC2C implements IService
{

    /**
     * Availability multithreading in this module
     *
     * @var array $_allow_multithreading
     */
    private $_allow_multithreading = false;

    /**
     * Checks if shipping service allows to use multithreading
     *
     * @return bool true if allow
     */
    public function allowMultithreading()
    {
        return $this->_allow_multithreading;
    }

    /**
     * Sets data to internal class variable
     *
     * @param array $shipping_info
     */
    public function prepareData($shipping_info)
    {
        $this->_shipping_info = $shipping_info;
    }

     /**
     * Gets shipping cost and information about possible errors
     *
     * @param  string $resonse Reponse from Shipping service server
     * @return array  Shipping cost and errors
     */
    public function processResponse($response)
    {
        if( $this->_shipping_info['package_info']['location']['country'] !='TW')
            $response['errors']='Error country, only supports Taiwan';
    
        return $response;
    }

    /**
     * Gets error message from shipping service server
     *
     * @param  string $resonse Reponse from Shipping service server
     * @return string Text of error or false if no errors
     */
    public function processErrors($response)
    {
  
      
        return null;
    }

    /**
     * Prepare request information
     *
     * @return null Always null (method not allowed)
     */
    public function getRequestData()
    {

        return null;
    }

    /**
     * Process simple request to shipping service server
     *
     * @return string Server response
     */
    public function getSimpleRates()
    {
        $return = array(
            'cost' => false,
            'error' => false,
        );

        if( $this->_shipping_info['service_params']['country_limit'] == 'Y' && $this->_shipping_info['package_info']['location']['country'] !='TW')
            $return['errors']='Error country, only supports Taiwan';
        else
            $return['cost']=0;
        return $return;
    }
}
?>